@@ -30,6 +30,7 @@ def retryloop(attempts, timeout=None, delay=0, backoff=1):
         except RetryError as e: pass
 
     # Decorate exception with retry information:
-    e.args = e.args + ("on attempt {0} of {1} after {2:.3f} seconds".format(i, attempts + 1, duration), )
+    e.args = e.args + ("on attempt {0} of {1} after {2:.3f} seconds".format(
+        i + 1, attempts + 1, duration), )
 
     raise
